aboutsummaryrefslogtreecommitdiff
path: root/bindings
diff options
context:
space:
mode:
authorRuben Beltran del Rio <ruben@unlimited.pizza>2023-10-04 15:22:05 +0200
committerRuben Beltran del Rio <ruben@unlimited.pizza>2023-10-04 15:22:05 +0200
commit20fe4b1e1cee75463cd63cfe202e05e0b61d941a (patch)
treea395e1b96c5bedb4c0e8833a82d8e7d636630e88 /bindings
parent5d5dd65cee63b8805a186d28660ed65072b3b88a (diff)
Simplify dir
Diffstat (limited to 'bindings')
-rw-r--r--bindings/rust/lib.rs6
1 files changed, 3 insertions, 3 deletions
diff --git a/bindings/rust/lib.rs b/bindings/rust/lib.rs
index 7bc923a..0bbddda 100644
--- a/bindings/rust/lib.rs
+++ b/bindings/rust/lib.rs
@@ -1,4 +1,4 @@
//! This crate provides api-notation language support for the [tree-sitter][] parsing library.
//!
//! Typically, you will use the [language][language func] function to add this language to a
//! tree-sitter [Parser][], and then use the parser to parse some code:
@@ -6,7 +6,7 @@
//! ```
//! let code = "";
//! let mut parser = tree_sitter::Parser::new();
-//! parser.set_language(tree_sitter_api_notation::language()).expect("Error loading api-notation grammar");
+//! parser.set_language(tree_sitter_api_notation::language()).expect("Error loading api_notation grammar");
//! let tree = parser.parse(code, None).unwrap();
//! ```
//!
@@ -47,6 +47,6 @@ mod tests {
let mut parser = tree_sitter::Parser::new();
parser
.set_language(super::language())
- .expect("Error loading api-notation language");
+ .expect("Error loading api_notation language");
}
}
@@ -1,4 +1,4 @@
-//! This crate provides api-notation language support for the [tree-sitter][] parsing library.
+//! This crate provides api_notation language support for the [tree-sitter][] parsing library.
//!
//! Typically, you will use the [language][language func] function to add this language to a